// Corners Effect
//
// Copyright Outerspace Software, all rights reserved

string description = "This effect adds little triangles at the corners of the texture.";

float4x4	WorldViewProjection;	
float4		UVBounds0 = float4(0,1,0,1);
float4		DiffuseCol;

//Tweakables
float	BorderSize = 0.1;

texture MyTexture0;
sampler MyTextureSampler0 = sampler_state{
    Texture   = (MyTexture0);
    AddressU  = CLAMP;
    AddressV  = CLAMP;
    MipFilter = LINEAR;
    MinFilter = LINEAR;
    MagFilter = LINEAR;
};

struct VS_INPUT{
	float4 position:	POSITION;
	float3 normal:		NORMAL;
	float3 diffuse:		COLOR;
	float2 tex:			TEXCOORD0;
};

struct VS_OUTPUT{
	float4 position:	POSITION;
	float2 tex:			TEXCOORD0;
};

struct PS_OUTPUT{
    float4 color:		COLOR;
};

VS_OUTPUT VS(VS_INPUT input){
	VS_OUTPUT output;      
	output.position = mul(input.position, WorldViewProjection);
	output.tex = input.tex;
	return output;
}

PS_OUTPUT PS(VS_OUTPUT input){
	PS_OUTPUT output;
	
	float2 t=input.tex;

	float xmin=abs(t.x-UVBounds0.x);
	float xmax=abs(t.x-UVBounds0.y);
	float ymin=abs(t.y-UVBounds0.z);
	float ymax=abs(t.y-UVBounds0.w);

	float b=BorderSize;
	
	if(xmin<b && ymin<b){
		if(ymin<(b-xmin))	DiffuseCol*=0.5;
	}
	if(xmin<b && ymax<b){
		if(ymax<(b-xmin))	DiffuseCol*=0.5;
	}
	if(xmax<b && ymin<b){
		if(xmax<(b-ymin))	DiffuseCol*=0.5;
	}
	if(xmax<b && ymax<b){
		if(xmax<(b-ymax))	DiffuseCol*=0.5;
	}
		
	output.color = tex2D(MyTextureSampler0, t) * DiffuseCol;    
	return output;
}

technique Shader
{
    pass P0
    {   
		VertexShader	= compile vs_1_1 VS();
		PixelShader		= compile ps_2_0 PS();
    }
}
